@@ -34,6 +34,7 @@
 #include "bombexplosionitem.h"
 #include "infooverlay.h"
 #include "infosidebar.h"
+#include "granatier_random.h"
 
 #include <KgTheme>
 #include <KgThemeProvider>
@@ -87,12 +88,12 @@ GameScene::GameScene(Game* p_game, KgThemeProvider* p_themeProvider) : m_game(p_
 
     // The remaining time
     m_remainingTimeLabel = new QGraphicsTextItem(i18n("0:00"));
-    m_remainingTimeLabel->setFont(QFont(QStringLiteral("Helvetica"), Granatier::CellSize * 0.35, QFont::Bold, false));
+    m_remainingTimeLabel->setFont(QFont(QStringLiteral("Helvetica"), static_cast<int>(Granatier::CellSize * 0.35), QFont::Bold, false));
     m_remainingTimeLabel->setDefaultTextColor(QColor("#FFFF00"));
     m_remainingTimeLabel->setZValue(1000);
 
     m_arenaNameLabel = new QGraphicsTextItem(i18n("Arena Name"));
-    m_arenaNameLabel->setFont(QFont(QStringLiteral("Helvetica"), Granatier::CellSize * 0.35, QFont::Bold, false));
+    m_arenaNameLabel->setFont(QFont(QStringLiteral("Helvetica"), static_cast<int>(Granatier::CellSize * 0.35), QFont::Bold, false));
     m_arenaNameLabel->setDefaultTextColor(QColor("#FFFF00"));
     m_arenaNameLabel->setZValue(1000);
 
@@ -258,8 +259,8 @@ void GameScene::init()
 
     //set the minimum size for the scene
     m_minSize = sceneRect();
-    int minWidth = (static_cast<int>(m_minSize.width() / Granatier::CellSize + 1.1)) * Granatier::CellSize;
-    int minHeight = (static_cast<int>(m_minSize.height() / Granatier::CellSize + 1.1)) * Granatier::CellSize;
+    int minWidth = static_cast<int>((m_minSize.width() / Granatier::CellSize + 1.1) * Granatier::CellSize);
+    int minHeight = static_cast<int>((m_minSize.height() / Granatier::CellSize + 1.1) * Granatier::CellSize);
     m_minSize.setX(m_minSize.x() + (m_minSize.width() - minWidth) / 10);
     m_minSize.setY(m_minSize.y() + (m_minSize.height() - minHeight) / 4);
     m_minSize.setWidth(minWidth);
@@ -343,7 +344,7 @@ void GameScene::initItemsWithGraphicsFromTheme()
             if (!blockElements.isEmpty())
             {
                 // Create the element item and set the image
-                foreach(Element* element, blockElements)
+                for(const auto& element: blockElements)
                 {
                     Block* block = dynamic_cast <Block*> (element);
                     BlockItem* blockItem = new BlockItem(block, m_rendererArenaItems);
@@ -405,7 +406,7 @@ void GameScene::initItemsWithGraphicsFromTheme()
                                 bonusItem->setSpriteKey(QStringLiteral("bonus_neutral_pandora"));
                         }
 
-                        if((qrand()/1.0)/RAND_MAX * 10 > 9 && bonusItem->spriteKey() != QStringLiteral("bonus_neutral_resurrect"))
+                        if(granatier::RNG::fromRange(0, 10) > 9 && bonusItem->spriteKey() != QStringLiteral("bonus_neutral_resurrect"))
                         {
                             bonusItem->setSpriteKey(QStringLiteral("bonus_neutral_pandora"));
                         }
@@ -438,7 +439,7 @@ void GameScene::initItemsWithGraphicsFromTheme()
     }
 
     // Create the Bomb items
-    foreach(Bomb* bomb, m_tempBombList)
+    for(auto& bomb: m_tempBombList)
     {
         createBombItem(bomb);
     }
@@ -668,8 +669,8 @@ void GameScene::resizeSprites(int delayForBackground)
     }
 
     //calculate the scaling factor for the SVGs
-    int horizontalPixelsPerCell = views().first()->size().width() / (m_minSize.width()/Granatier::CellSize);
-    int verticalPixelsPerCell = views().first()->size().height() / (m_minSize.height()/Granatier::CellSize);
+    int horizontalPixelsPerCell = static_cast<int>(views().first()->size().width() / (m_minSize.width()/Granatier::CellSize));
+    int verticalPixelsPerCell = static_cast<int>(views().first()->size().height() / (m_minSize.height()/Granatier::CellSize));
     if(horizontalPixelsPerCell < verticalPixelsPerCell)
     {
         m_SvgScaleFactor = Granatier::CellSize / horizontalPixelsPerCell;
@@ -919,7 +920,7 @@ void GameScene::bombDetonated(Bomb* bomb)
     {
         bombElements = m_game->getArena()->getCell(nRow, nColumn).getElements(Granatier::Element::BOMB);
         int tempBombDetonationCountdown = nDetonationCountdown;
-        foreach(Element* element, bombElements)
+        for(const auto& element: bombElements)
         {
             if(dynamic_cast <Bomb*> (element) != bomb && !(dynamic_cast <Bomb*> (element)->isDetonated()))
             {
@@ -931,7 +932,7 @@ void GameScene::bombDetonated(Bomb* bomb)
         blockElements = m_game->getArena()->getCell(nRow, nColumn).getElements(Granatier::Element::BLOCK);
         if(!blockElements.isEmpty())
         {
-            foreach(Element* element, blockElements)
+            for(const auto& element: blockElements)
             {
                 dynamic_cast <Block*> (element)->startDestruction();
                 if (m_blockItems[nRow][nColumn] != nullptr)
@@ -986,7 +987,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                 {
                     int tempBombDetonationCountdown = anDirectionDetonationCountdown[direction];
                     bool increaseDetonationTimeout = false;
-                    foreach(Element* element, bombElements)
+                    for(const auto& element: bombElements)
                     {
                         if(dynamic_cast <Bomb*> (element) != bomb && !(dynamic_cast <Bomb*> (element)->isDetonated()))
                         {
@@ -1003,7 +1004,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                     if(!blockElements.isEmpty())
                     {
                         abDirectionsDone[direction] = true;
-                        foreach(Element* element, blockElements)
+                        for(const auto& element: blockElements)
                         {
                             dynamic_cast <Block*> (element)->startDestruction();
                             if (m_blockItems[nRow][nColumn] != nullptr)
